==> helidon-docs-4.0.3.jar: pages/mp/introduction/microprofile.js <==
<doc-view>

<v-layout row wrap>
<v-flex xs12 sm10 lg10>
<v-card class="section-def" v-bind:color="$store.state.currentColor">
<v-card-text class="pa-3">
<v-card class="section-def__card">
<v-card-text>
<dl>
<dt slot=title>Helidon MicroProfile</dt>
<dd slot="desc"><p>Complete these tasks to get started with your MicroProfile application.</p>
</dd>
</dl>
</v-card-text>
</v-card>
</v-card-text>
</v-card>
</v-flex>
</v-layout>


<h2 id="_getting_started_with_helidon_microprofile">Getting Started with Helidon MicroProfile</h2>
<div class="section">
<p>Helidon provides a MicroProfile server implementation (<code>io.helidon.microprofile.server</code>) that
encapsulates the Helidon WebServer. You can either instantiate the server directly
as is done in the <router-link to="/mp/guides/quickstart">Helidon MP Quickstart example</router-link>
or use its built-in <code>main</code> as shown below.</p>


<h3 id="_maven_coordinates">Maven Coordinates</h3>
<div class="section">
<p>The <router-link to="/about/managing-dependencies">Managing Dependencies</router-link> page describes
how you should declare dependency management for Helidon applications.
Then declare the following dependency in your project:</p>

<markup
lang="xml"
title="Maven Dependency for full MicroProfile"
>&lt;dependency&gt;
  &lt;groupId&gt;io.helidon.microprofile.bundles&lt;/groupId&gt;
  &lt;artifactId&gt;helidon-microprofile&lt;/artifactId&gt;
&lt;/dependency&gt;</markup>

<p>The above dependency adds all the features available in MicroProfile. If you
want to start with a smaller core set of features then you can use the
<code>core</code> bundle instead. This bundle includes the base feature in MicroProfile
(such as JAX-RS, CDI, JSON-P/B, and Config) and leaves out some of the
additional features such as Metrics and Tracing. You can add those dependencies
individually if you choose.</p>

<markup
lang="xml"
title="Maven Dependency for MicroProfile core features only"
>&lt;dependency&gt;
  &lt;groupId&gt;io.helidon.microprofile.bundles&lt;/groupId&gt;
  &lt;artifactId&gt;helidon-microprofile-core&lt;/artifactId&gt;
&lt;/dependency&gt;</markup>

</div>


<h3 id="_project_files">Project files</h3>
<div class="section">
<p>Create a JAX-RS Resource class with at least one resource method.</p>

<markup
lang="java"
title="Sample JAX-RS Resource Class"
>@Path("/")
@RequestScoped
public class HelloWorldResource {
    @GET
    @Produces(MediaType.TEXT_PLAIN)
    public String message() {
        return "Hello World";
    }
}</markup>

<p>And create a JAX-RS application.</p>

<markup
lang="java"
title="Sample JAX-RS Application"
>@ApplicationScoped
@ApplicationPath("/")
public class HelloWorldApplication extends Application {
    @Override
    public Set&lt;Class&lt;?&gt;&gt; getClasses() {
        return Set.of(
                HelloWorldResource.class
        );
    }
}</markup>

<p>Add <code>beans.xml</code> in <code>src/main/resources/META-INF</code> so
the CDI implementation can pick up your classes.</p>

<markup
lang="xml"
title="beans.xml"
>&lt;?xml version="1.0" encoding="UTF-8"?&gt;
&lt;beans/&gt;</markup>

<p>As a last step, add a main method to your application (or a dedicated Main class)
 to start everything up.</p>

<markup
lang="java"
title="Sample JAX-RS Application"
>public static void main(String[] args) {
    io.helidon.microprofile.server.Main.main(args);
}</markup>

<p>Run the main class. The server will start on port 7001 and serve your
 resources.</p>

</div>


<h3 id="_adding_jandex">Adding Jandex</h3>
<div class="section">
<p>Jandex is an indexing tool for Weld (the CDI implementation used by Helidon) that helps speed up
the boot time of an application.</p>

<p>To use Jandex, configure a Maven plugin that adds the index to your
 JAR file and a dependency on Jandex.</p>

<markup
lang="xml"
title="jandex dependency"
>&lt;dependency&gt;
    &lt;groupId&gt;io.smallrye&lt;/groupId&gt;
    &lt;artifactId&gt;jandex&lt;/artifactId&gt;
    &lt;version&gt;{version.plugin.jandex}&lt;/version&gt;
&lt;/dependency&gt;</markup>

<markup
lang="xml"
title="jandex plugin configuration"
>&lt;build&gt;
    &lt;plugins&gt;
        &lt;plugin&gt;
            &lt;groupId&gt;io.smallrye&lt;/groupId&gt;
            &lt;artifactId&gt;jandex-maven-plugin&lt;/artifactId&gt;
            &lt;version&gt;3.1.2&lt;/version&gt;
            &lt;executions&gt;
                &lt;execution&gt;
                    &lt;id&gt;make-index&lt;/id&gt;
                    &lt;goals&gt;
                        &lt;goal&gt;jandex&lt;/goal&gt;
                    &lt;/goals&gt;
                    &lt;phase&gt;process-classes&lt;/phase&gt;
                &lt;/execution&gt;
            &lt;/executions&gt;
        &lt;/plugin&gt;
    &lt;/plugins&gt;
&lt;/build&gt;</markup>

</div>

</div>

</doc-view>

==> helidon-docs-4.0.8.jar: pages/mp/introduction/microprofile.js <==
<doc-view>

<v-layout row wrap>
<v-flex xs12 sm10 lg10>
<v-card class="section-def" v-bind:color="$store.state.currentColor">
<v-card-text class="pa-3">
<v-card class="section-def__card">
<v-card-text>
<dl>
<dt slot=title>Helidon MicroProfile</dt>
<dd slot="desc"><p>Complete these tasks to get started with your MicroProfile application.</p>
</dd>
</dl>
</v-card-text>
</v-card>
</v-card-text>
</v-card>
</v-flex>
</v-layout>


<h2 id="_getting_started_with_helidon_microprofile">Getting Started with Helidon MicroProfile</h2>
<div class="section">
<p>Helidon provides a MicroProfile server implementation (<code>io.helidon.microprofile.server</code>) that
encapsulates the Helidon WebServer. You can either instantiate the server directly
as is done in the <router-link to="/mp/guides/quickstart">Helidon MP Quickstart example</router-link>
or use its built-in <code>main</code> as shown below.</p>


<h3 id="_maven_coordinates">Maven Coordinates</h3>
<div class="section">
<p>The <router-link to="/about/managing-dependencies">Managing Dependencies</router-link> page describes
how you should declare dependency management for Helidon applications.
Then declare the following dependency in your project:</p>

<markup
lang="xml"
title="Maven Dependency for full MicroProfile"
>&lt;dependency&gt;
  &lt;groupId&gt;io.helidon.microprofile.bundles&lt;/groupId&gt;
  &lt;artifactId&gt;helidon-microprofile&lt;/artifactId&gt;
&lt;/dependency&gt;</markup>

<p>The above dependency adds all the features available in MicroProfile. If you
want to start with a smaller core set of features then you can use the
<code>core</code> bundle instead. This bundle includes the base feature in MicroProfile
(such as JAX-RS, CDI, JSON-P/B, and Config) and leaves out some of the
additional features such as Metrics and Tracing. You can add those dependencies
individually if you choose.</p>

<markup
lang="xml"
title="Maven Dependency for MicroProfile core features only"
>&lt;dependency&gt;
  &lt;groupId&gt;io.helidon.microprofile.bundles&lt;/groupId&gt;
  &lt;artifactId&gt;helidon-microprofile-core&lt;/artifactId&gt;
&lt;/dependency&gt;</markup>

</div>


<h3 id="_project_files">Project files</h3>
<div class="section">
<p>Create a JAX-RS Resource class with at least one resource method.</p>

<markup
lang="java"
title="Sample JAX-RS Resource Class"
>@Path("/")
@RequestScoped
public class HelloWorldResource {
    @GET
    @Produces(MediaType.TEXT_PLAIN)
    public String message() {
        return "Hello World";
    }
}</markup>

<p>And create a JAX-RS application.</p>

<markup
lang="java"
title="Sample JAX-RS Application"
>@ApplicationScoped
@ApplicationPath("/")
public class HelloWorldApplication extends Application {
    @Override
    public Set&lt;Class&lt;?&gt;&gt; getClasses() {
        return Set.of(
                HelloWorldResource.class
        );
    }
}</markup>

<p>Add <code>beans.xml</code> in <code>src/main/resources/META-INF</code> so
the CDI implementation can pick up your classes.</p>

<markup
lang="xml"
title="beans.xml"
>&lt;?xml version="1.0" encoding="UTF-8"?&gt;
&lt;beans/&gt;</markup>

<p>As a last step, add a main method to your application (or a dedicated Main class)
 to start everything up.</p>

<markup
lang="java"
title="Sample JAX-RS Application"
>public static void main(String[] args) {
    io.helidon.microprofile.cdi.Main.main(args);
}</markup>

<p>Run the main class. The server will start on port 7001 and serve your
 resources.</p>

</div>


<h3 id="_adding_jandex">Adding Jandex</h3>
<div class="section">
<p>Jandex is an indexing tool for Weld (the CDI implementation used by Helidon) that helps speed up
the boot time of an application.</p>

<p>To use Jandex, configure a Maven plugin that adds the index to your
 JAR file and a dependency on Jandex.</p>

<markup
lang="xml"
title="jandex dependency"
>&lt;dependency&gt;
    &lt;groupId&gt;io.smallrye&lt;/groupId&gt;
    &lt;artifactId&gt;jandex&lt;/artifactId&gt;
    &lt;version&gt;{version.plugin.jandex}&lt;/version&gt;
&lt;/dependency&gt;</markup>

<markup
lang="xml"
title="jandex plugin configuration"
>&lt;build&gt;
    &lt;plugins&gt;
        &lt;plugin&gt;
            &lt;groupId&gt;io.smallrye&lt;/groupId&gt;
            &lt;artifactId&gt;jandex-maven-plugin&lt;/artifactId&gt;
            &lt;version&gt;3.1.2&lt;/version&gt;
            &lt;executions&gt;
                &lt;execution&gt;
                    &lt;id&gt;make-index&lt;/id&gt;
                    &lt;goals&gt;
                        &lt;goal&gt;jandex&lt;/goal&gt;
                    &lt;/goals&gt;
                    &lt;phase&gt;process-classes&lt;/phase&gt;
                &lt;/execution&gt;
            &lt;/executions&gt;
        &lt;/plugin&gt;
    &lt;/plugins&gt;
&lt;/build&gt;</markup>

</div>

</div>

</doc-view>
